@@ -255,37 +255,28 @@ class RequestHandler(tornado.web.RequestHandler):
         self.auth_callback = self.application.settings.get('auth_callback', NotImplemented)
 
         self.db = self.application.settings.get('db', NotImplemented)
-        # self.acct_db = self.application.settings.get('acct_db', NotImplemented)
+        self.acct_db = self.application.settings.get('acct_db', NotImplemented)
 
         self.cache_db = self.application.settings.get('cache_db', NotImplemented)
         self.session = self.application.settings.get('session', NotImplemented)
 
         #
-        # self.files_db = self.application.settings.get('files_db', NotImplemented)
-        # self.dbs = self.application.settings.get('dbs', NotImplemented)
+        self.files_db = self.application.settings.get('files_db', NotImplemented)
+        self.dbs = self.application.settings.get('dbs', NotImplemented)
 
         self.statsd = self.application.settings.get('statsd', NotImplemented)
-
-        # mail client
-        _smtp_config = self.application.settings.get('smtp')
-        if _smtp_config:
-            self.smtp = MailClient2(_smtp_config)
-        else:
-            self.smtp = None
+        self.smtp = self.application.settings.get('smtp', NotImplemented)
 
         # self.smtp=None
         # self.db = None
-        self.acct_db = None
+        # self.acct_db = None
         # self.cache_db=None
         # self.session=None
-        self.files_db=None
-        self.dbs=None
-
+        # self.files_db=None
+        # self.dbs=None
         # self.statsd=None
 
 
-
-
         self.locale_callback = self.application.settings.get('locale_callback', NotImplemented)
         self.hacking_ie = None
 
